@@ -310,7 +310,8 @@ func (b *Build) createReferees(executor Executor) {
 }
 
 func (b *Build) executeUploadReferees(ctx context.Context, startTime time.Time, endTime time.Time) {
-	if b.Referees == nil {
+	if b.Referees == nil || b.ArtifactUploader == nil {
+		b.Log().Debug("Skipping referees execution")
 		return
 	}
 
