@@ -20,13 +20,13 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 	"github.com/stretchr/testify/require"
-
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
+	service_test "gitlab.com/gitlab-org/gitlab-runner/helpers/container/services/test"
 	docker_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
@@ -93,36 +93,36 @@ type testAllowedImageDescription struct {
 
 var testAllowedImages = []testAllowedImageDescription{
 	{true, "ruby", []string{"*"}},
-	{true, "ruby:2.1", []string{"*"}},
+	{true, "ruby:2.6", []string{"*"}},
 	{true, "ruby:latest", []string{"*"}},
 	{true, "library/ruby", []string{"*/*"}},
-	{true, "library/ruby:2.1", []string{"*/*"}},
-	{true, "library/ruby:2.1", []string{"*/*:*"}},
+	{true, "library/ruby:2.6", []string{"*/*"}},
+	{true, "library/ruby:2.6", []string{"*/*:*"}},
 	{true, "my.registry.tld/library/ruby", []string{"my.registry.tld/*/*"}},
-	{true, "my.registry.tld/library/ruby:2.1", []string{"my.registry.tld/*/*:*"}},
+	{true, "my.registry.tld/library/ruby:2.6", []string{"my.registry.tld/*/*:*"}},
 	{true, "my.registry.tld/group/subgroup/ruby", []string{"my.registry.tld/*/*/*"}},
-	{true, "my.registry.tld/group/subgroup/ruby:2.1", []string{"my.registry.tld/*/*/*:*"}},
+	{true, "my.registry.tld/group/subgroup/ruby:2.6", []string{"my.registry.tld/*/*/*:*"}},
 	{true, "ruby", []string{"**/*"}},
-	{true, "ruby:2.1", []string{"**/*"}},
+	{true, "ruby:2.6", []string{"**/*"}},
 	{true, "ruby:latest", []string{"**/*"}},
 	{true, "library/ruby", []string{"**/*"}},
-	{true, "library/ruby:2.1", []string{"**/*"}},
-	{true, "library/ruby:2.1", []string{"**/*:*"}},
+	{true, "library/ruby:2.6", []string{"**/*"}},
+	{true, "library/ruby:2.6", []string{"**/*:*"}},
 	{true, "my.registry.tld/library/ruby", []string{"my.registry.tld/**/*"}},
-	{true, "my.registry.tld/library/ruby:2.1", []string{"my.registry.tld/**/*:*"}},
+	{true, "my.registry.tld/library/ruby:2.6", []string{"my.registry.tld/**/*:*"}},
 	{true, "my.registry.tld/group/subgroup/ruby", []string{"my.registry.tld/**/*"}},
-	{true, "my.registry.tld/group/subgroup/ruby:2.1", []string{"my.registry.tld/**/*:*"}},
+	{true, "my.registry.tld/group/subgroup/ruby:2.6", []string{"my.registry.tld/**/*:*"}},
 	{false, "library/ruby", []string{"*"}},
-	{false, "library/ruby:2.1", []string{"*"}},
+	{false, "library/ruby:2.6", []string{"*"}},
 	{false, "my.registry.tld/ruby", []string{"*"}},
-	{false, "my.registry.tld/ruby:2.1", []string{"*"}},
+	{false, "my.registry.tld/ruby:2.6", []string{"*"}},
 	{false, "my.registry.tld/library/ruby", []string{"*"}},
-	{false, "my.registry.tld/library/ruby:2.1", []string{"*"}},
+	{false, "my.registry.tld/library/ruby:2.6", []string{"*"}},
 	{false, "my.registry.tld/group/subgroup/ruby", []string{"*"}},
-	{false, "my.registry.tld/group/subgroup/ruby:2.1", []string{"*"}},
+	{false, "my.registry.tld/group/subgroup/ruby:2.6", []string{"*"}},
 	{false, "library/ruby", []string{"*/*:*"}},
 	{false, "my.registry.tld/group/subgroup/ruby", []string{"my.registry.tld/*/*"}},
-	{false, "my.registry.tld/group/subgroup/ruby:2.1", []string{"my.registry.tld/*/*:*"}},
+	{false, "my.registry.tld/group/subgroup/ruby:2.6", []string{"my.registry.tld/*/*:*"}},
 	{false, "library/ruby", []string{"**/*:*"}},
 }
 
@@ -140,58 +140,6 @@ func TestVerifyAllowedImage(t *testing.T) {
 	}
 }
 
-type testServiceDescription struct {
-	description string
-	image       string
-	service     string
-	version     string
-	alias       string
-	alternative string
-}
-
-var testServices = []testServiceDescription{
-	{"service", "service:latest", "service", "latest", "service", ""},
-	{"service:version", "service:version", "service", "version", "service", ""},
-	{"namespace/service", "namespace/service:latest", "namespace/service", "latest", "namespace__service", "namespace-service"},
-	{"namespace/service:version", "namespace/service:version", "namespace/service", "version", "namespace__service", "namespace-service"},
-	{"domain.tld/service", "domain.tld/service:latest", "domain.tld/service", "latest", "domain.tld__service", "domain.tld-service"},
-	{"domain.tld/service:version", "domain.tld/service:version", "domain.tld/service", "version", "domain.tld__service", "domain.tld-service"},
-	{"domain.tld/namespace/service", "domain.tld/namespace/service:latest", "domain.tld/namespace/service", "latest", "domain.tld__namespace__service", "domain.tld-namespace-service"},
-	{"domain.tld/namespace/service:version", "domain.tld/namespace/service:version", "domain.tld/namespace/service", "version", "domain.tld__namespace__service", "domain.tld-namespace-service"},
-	{"domain.tld:8080/service", "domain.tld:8080/service:latest", "domain.tld/service", "latest", "domain.tld__service", "domain.tld-service"},
-	{"domain.tld:8080/service:version", "domain.tld:8080/service:version", "domain.tld/service", "version", "domain.tld__service", "domain.tld-service"},
-	{"domain.tld:8080/namespace/service", "domain.tld:8080/namespace/service:latest", "domain.tld/namespace/service", "latest", "domain.tld__namespace__service", "domain.tld-namespace-service"},
-	{"domain.tld:8080/namespace/service:version", "domain.tld:8080/namespace/service:version", "domain.tld/namespace/service", "version", "domain.tld__namespace__service", "domain.tld-namespace-service"},
-	{"subdomain.domain.tld:8080/service", "subdomain.domain.tld:8080/service:latest", "subdomain.domain.tld/service", "latest", "subdomain.domain.tld__service", "subdomain.domain.tld-service"},
-	{"subdomain.domain.tld:8080/service:version", "subdomain.domain.tld:8080/service:version", "subdomain.domain.tld/service", "version", "subdomain.domain.tld__service", "subdomain.domain.tld-service"},
-	{"subdomain.domain.tld:8080/namespace/service", "subdomain.domain.tld:8080/namespace/service:latest", "subdomain.domain.tld/namespace/service", "latest", "subdomain.domain.tld__namespace__service", "subdomain.domain.tld-namespace-service"},
-	{"subdomain.domain.tld:8080/namespace/service:version", "subdomain.domain.tld:8080/namespace/service:version", "subdomain.domain.tld/namespace/service", "version", "subdomain.domain.tld__namespace__service", "subdomain.domain.tld-namespace-service"},
-}
-
-func testSplitService(t *testing.T, test testServiceDescription) {
-	e := executor{}
-	service, version, imageName, linkNames := e.splitServiceAndVersion(test.description)
-
-	assert.Equal(t, test.service, service, "service for "+test.description)
-	assert.Equal(t, test.version, version, "version for "+test.description)
-	assert.Equal(t, test.image, imageName, "image for "+test.description)
-	assert.Equal(t, test.alias, linkNames[0], "alias for "+test.description)
-	if test.alternative != "" {
-		assert.Len(t, linkNames, 2, "linkNames len for "+test.description)
-		assert.Equal(t, test.alternative, linkNames[1], "alternative for "+test.description)
-	} else {
-		assert.Len(t, linkNames, 1, "linkNames len for "+test.description)
-	}
-}
-
-func TestSplitService(t *testing.T) {
-	for _, test := range testServices {
-		t.Run(test.description, func(t *testing.T) {
-			testSplitService(t, test)
-		})
-	}
-}
-
 func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName string) {
 	var c docker_helpers.MockClient
 	defer c.AssertExpectations(t)
@@ -271,9 +219,9 @@ func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName
 }
 
 func TestServiceFromNamedImage(t *testing.T) {
-	for _, test := range testServices {
-		t.Run(test.description, func(t *testing.T) {
-			testServiceFromNamedImage(t, test.description, test.image, test.service)
+	for _, test := range service_test.TestServices {
+		t.Run(test.Description, func(t *testing.T) {
+			testServiceFromNamedImage(t, test.Description, test.Image, test.Service)
 		})
 	}
 }
@@ -979,7 +927,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			createVolumeManager: true,
 		},
 		"git strategy fetch, non-empty buildsDir, no error, legacy builds dir": {
-			// TODO: Remove in 12.3
+			// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
 			gitStrategy: "fetch",
 			buildsDir:   "/builds",
 			adjustConfiguration: func(e *executor) {
@@ -996,7 +944,7 @@ func TestCreateBuildVolume(t *testing.T) {
 			createVolumeManager: true,
 		},
 		"git strategy clone, non-empty buildsDir, no error, legacy builds dir": {
-			// TODO: Remove in 12.3
+			// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
 			gitStrategy: "clone",
 			buildsDir:   "/builds",
 			adjustConfiguration: func(e *executor) {
@@ -1036,7 +984,7 @@ func TestCreateDependencies(t *testing.T) {
 			legacyVolumesMountingOrder: "false",
 			expectedServiceVolumes:     []string{"/volume", "/builds"},
 		},
-		// TODO: Remove in 12.6
+		// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/6581
 		"UseLegacyVolumesMountingOrder is true": {
 			legacyVolumesMountingOrder: "true",
 			expectedServiceVolumes:     []string{"/builds"},
