@@ -2,11 +2,13 @@ package kubernetes
 
 import (
 	"encoding/json"
+	"errors"
 	"fmt"
 	"strings"
 	"sync"
 
 	"github.com/sirupsen/logrus"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/services"
 	"golang.org/x/net/context"
 	api "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -16,8 +18,8 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/executors"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/dns"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker/helperimage"
 	"gitlab.com/gitlab-org/gitlab-runner/session/proxy"
 )
 
@@ -65,6 +67,8 @@ type executor struct {
 	pullPolicy              common.KubernetesPullPolicy
 
 	helperImageInfo helperimage.Info
+
+	featureChecker featureChecker
 }
 
 type serviceDeleteResponse struct {
@@ -82,28 +86,28 @@ func (s *executor) setupResources() error {
 
 	// Limit
 	if s.buildLimits, err = limits(s.Config.Kubernetes.CPULimit, s.Config.Kubernetes.MemoryLimit); err != nil {
-		return fmt.Errorf("invalid build limits specified: %s", err.Error())
+		return fmt.Errorf("invalid build limits specified: %w", err)
 	}
 
 	if s.serviceLimits, err = limits(s.Config.Kubernetes.ServiceCPULimit, s.Config.Kubernetes.ServiceMemoryLimit); err != nil {
-		return fmt.Errorf("invalid service limits specified: %s", err.Error())
+		return fmt.Errorf("invalid service limits specified: %w", err)
 	}
 
 	if s.helperLimits, err = limits(s.Config.Kubernetes.HelperCPULimit, s.Config.Kubernetes.HelperMemoryLimit); err != nil {
-		return fmt.Errorf("invalid helper limits specified: %s", err.Error())
+		return fmt.Errorf("invalid helper limits specified: %w", err)
 	}
 
 	// Requests
 	if s.buildRequests, err = limits(s.Config.Kubernetes.CPURequest, s.Config.Kubernetes.MemoryRequest); err != nil {
-		return fmt.Errorf("invalid build requests specified: %s", err.Error())
+		return fmt.Errorf("invalid build requests specified: %w", err)
 	}
 
 	if s.serviceRequests, err = limits(s.Config.Kubernetes.ServiceCPURequest, s.Config.Kubernetes.ServiceMemoryRequest); err != nil {
-		return fmt.Errorf("invalid service requests specified: %s", err.Error())
+		return fmt.Errorf("invalid service requests specified: %w", err)
 	}
 
 	if s.helperRequests, err = limits(s.Config.Kubernetes.HelperCPURequest, s.Config.Kubernetes.HelperMemoryRequest); err != nil {
-		return fmt.Errorf("invalid helper requests specified: %s", err.Error())
+		return fmt.Errorf("invalid helper requests specified: %w", err)
 	}
 	return nil
 }
@@ -136,9 +140,11 @@ func (s *executor) Prepare(options common.ExecutorPrepareOptions) (err error) {
 	}
 
 	if s.kubeClient, err = getKubeClient(options.Config.Kubernetes, s.configurationOverwrites); err != nil {
-		return fmt.Errorf("error connecting to Kubernetes: %s", err.Error())
+		return fmt.Errorf("error connecting to Kubernetes: %w", err)
 	}
 
+	s.featureChecker = &kubeClientFeatureChecker{kubeClient: s.kubeClient}
+
 	s.Println("Using Kubernetes executor with image", s.options.Image.Name, "...")
 
 	return nil
@@ -475,8 +481,79 @@ func (s *executor) setupCredentials() error {
 	return nil
 }
 
+type invalidHostAliasDNSError struct {
+	service common.Image
+	inner   error
+}
+
+func (e *invalidHostAliasDNSError) Error() string {
+	return fmt.Sprintf(
+		"provided host alias %s for service %s is invalid DNS. %s",
+		e.service.Alias,
+		e.service.Name,
+		e.inner,
+	)
+}
+
+func (e *invalidHostAliasDNSError) Is(err error) bool {
+	_, ok := err.(*invalidHostAliasDNSError)
+	return ok
+}
+
+func (s *executor) prepareHostAlias() (*api.HostAlias, error) {
+	supportsHostAliases, err := s.featureChecker.IsHostAliasSupported()
+	if errors.Is(err, &badVersionError{}) {
+		s.Warningln("Checking for host alias support. Host aliases will be disabled.", err)
+		return nil, nil
+	} else if err != nil {
+		return nil, err
+	} else if !supportsHostAliases {
+		return nil, nil
+	}
+
+	return s.createHostAlias()
+}
+
+func (s *executor) createHostAlias() (*api.HostAlias, error) {
+	servicesHostAlias := api.HostAlias{IP: "127.0.0.1"}
+
+	for _, service := range s.options.Services {
+		// Services with ports are coming from .gitlab-webide.yml
+		// they are used for ports mapping and their aliases are in no way validated
+		// so we ignore them. Check out https://gitlab.com/gitlab-org/gitlab-runner/merge_requests/1170
+		// for details
+		if len(service.Ports) > 0 {
+			continue
+		}
+
+		serviceMeta := services.SplitNameAndVersion(service.Name)
+		for _, alias := range serviceMeta.Aliases {
+			// For backward compatibility reasons a non DNS1123 compliant alias might be generated,
+			// this will be removed in https://gitlab.com/gitlab-org/gitlab-runner/issues/6100
+			err := dns.ValidateDNS1123Subdomain(alias)
+			if err == nil {
+				servicesHostAlias.Hostnames = append(servicesHostAlias.Hostnames, alias)
+			}
+		}
+
+		if service.Alias == "" {
+			continue
+		}
+
+		err := dns.ValidateDNS1123Subdomain(service.Alias)
+		if err != nil {
+			return nil, &invalidHostAliasDNSError{service: service, inner: err}
+		}
+
+		servicesHostAlias.Hostnames = append(servicesHostAlias.Hostnames, service.Alias)
+	}
+
+	return &servicesHostAlias, nil
+}
+
 func (s *executor) setupBuildPod() error {
 	services := make([]api.Container, len(s.options.Services))
+
 	for i, service := range s.options.Services {
 		resolvedImage := s.Build.GetAllVariables().ExpandValue(service.Name)
 		services[i] = s.buildContainer(fmt.Sprintf("svc-%d", i), resolvedImage, service, s.serviceRequests, s.serviceLimits)
@@ -503,7 +580,12 @@ func (s *executor) setupBuildPod() error {
 		imagePullSecrets = append(imagePullSecrets, api.LocalObjectReference{Name: s.credentials.Name})
 	}
 
-	podConfig := s.preparePodConfig(labels, annotations, services, imagePullSecrets)
+	hostAlias, err := s.prepareHostAlias()
+	if err != nil {
+		return err
+	}
+
+	podConfig := s.preparePodConfig(labels, annotations, services, imagePullSecrets, hostAlias)
 
 	pod, err := s.kubeClient.CoreV1().Pods(s.configurationOverwrites.namespace).Create(&podConfig)
 	if err != nil {
@@ -519,10 +601,10 @@ func (s *executor) setupBuildPod() error {
 	return nil
 }
 
-func (s *executor) preparePodConfig(labels, annotations map[string]string, services []api.Container, imagePullSecrets []api.LocalObjectReference) api.Pod {
+func (s *executor) preparePodConfig(labels, annotations map[string]string, services []api.Container, imagePullSecrets []api.LocalObjectReference, hostAlias *api.HostAlias) api.Pod {
 	buildImage := s.Build.GetAllVariables().ExpandValue(s.options.Image.Name)
 
-	return api.Pod{
+	pod := api.Pod{
 		ObjectMeta: metav1.ObjectMeta{
 			GenerateName: s.projectUniqueName(),
 			Namespace:    s.configurationOverwrites.namespace,
@@ -545,6 +627,12 @@ func (s *executor) preparePodConfig(labels, annotations map[string]string, servi
 			SecurityContext:               s.Config.Kubernetes.GetPodSecurityContext(),
 		},
 	}
+
+	if hostAlias != nil {
+		pod.Spec.HostAliases = []api.HostAlias{*hostAlias}
+	}
+
+	return pod
 }
 
 func (s *executor) getHelperImage() string {
@@ -581,7 +669,7 @@ func (s *executor) makePodProxyServices() ([]api.Service, error) {
 	var services []api.Service
 	for res := range ch {
 		if res.err != nil {
-			err := fmt.Errorf("error creating the proxy service %q: %v", res.service.Name, res.err)
+			err := fmt.Errorf("error creating the proxy service %q: %w", res.service.Name, res.err)
 			s.Errorln(err)
 
 			return []api.Service{}, err
