@@ -58,6 +58,8 @@ type client struct {
 	lastUpdate      string
 	requestBackOffs map[string]*backoff.Backoff
 	lock            sync.Mutex
+
+	requester requester
 }
 
 type ResponseTLSData struct {
@@ -192,21 +194,13 @@ func (n *client) backoffRequired(res *http.Response) bool {
 	return res.StatusCode >= 400 && res.StatusCode < 600
 }
 
-func (n *client) doBackoffRequest(req *http.Request) (res *http.Response, err error) {
-	res, err = n.Do(req)
-	if err != nil {
-		err = fmt.Errorf("couldn't execute %v against %s: %v", req.Method, req.URL, err)
-		return
-	}
-
+func (n *client) checkBackoffRequest(req *http.Request, res *http.Response) {
 	backoffDelay := n.ensureBackoff(req.Method, req.RequestURI)
 	if n.backoffRequired(res) {
 		time.Sleep(backoffDelay.Duration())
 	} else {
 		backoffDelay.Reset()
 	}
-
-	return
 }
 
 func (n *client) do(uri, method string, request io.Reader, requestType string, headers http.Header) (res *http.Response, err error) {
@@ -217,7 +211,7 @@ func (n *client) do(uri, method string, request io.Reader, requestType string, h
 
 	req, err := http.NewRequest(method, url.String(), request)
 	if err != nil {
-		err = fmt.Errorf("failed to create NewRequest: %v", err)
+		err = fmt.Errorf("failed to create NewRequest: %w", err)
 		return
 	}
 
@@ -232,7 +226,12 @@ func (n *client) do(uri, method string, request io.Reader, requestType string, h
 
 	n.ensureTLSConfig()
 
-	res, err = n.doBackoffRequest(req)
+	res, err = n.requester.Do(req)
+	if err != nil {
+		return
+	}
+
+	n.checkBackoffRequest(req, res)
 	return
 }
 
@@ -287,7 +286,7 @@ func (n *client) getResponseTLSData(TLS *tls.ConnectionState) (ResponseTLSData,
 
 	caChain, err := n.buildCAChain(TLS)
 	if err != nil {
-		return TLSData, fmt.Errorf("couldn't build CA Chain: %v", err)
+		return TLSData, fmt.Errorf("couldn't build CA Chain: %w", err)
 	}
 
 	TLSData.CAChain = caChain
@@ -307,7 +306,7 @@ func (n *client) buildCAChain(tls *tls.ConnectionState) (string, error) {
 	builder := ca_chain.NewBuilder(logrus.StandardLogger())
 	err := builder.BuildChainFromTLSConnectionState(tls)
 	if err != nil {
-		return "", fmt.Errorf("error while fetching certificates from TLS ConnectionState: %v", err)
+		return "", fmt.Errorf("error while fetching certificates from TLS ConnectionState: %w", err)
 	}
 
 	return builder.String(), nil
@@ -318,7 +317,7 @@ func isResponseApplicationJSON(res *http.Response) (result bool, err error) {
 
 	mimetype, _, err := mime.ParseMediaType(contentType)
 	if err != nil {
-		return false, fmt.Errorf("Content-Type parsing error: %v", err)
+		return false, fmt.Errorf("Content-Type parsing error: %w", err)
 	}
 
 	if mimetype != "application/json" {
@@ -364,6 +363,7 @@ func newClient(requestCredentials requestCredentials) (c *client, err error) {
 		keyFile:         requestCredentials.GetTLSKeyFile(),
 		requestBackOffs: make(map[string]*backoff.Backoff),
 	}
+	c.requester = newRateLimitRequester(&c.Client)
 
 	host := strings.Split(url.Host, ":")[0]
 	if CertificateDirectory != "" {
