@@ -12,6 +12,7 @@ import (
 	"strconv"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
@@ -342,7 +343,7 @@ func getRequestJobResponse() (res map[string]interface{}) {
 	res["steps"] = steps
 
 	image := make(map[string]interface{})
-	image["name"] = "ruby:2.0"
+	image["name"] = "ruby:2.6"
 	image["entrypoint"] = []string{"/bin/sh"}
 	res["image"] = image
 
@@ -480,7 +481,7 @@ func TestRequestJob(t *testing.T) {
 	}
 	assert.True(t, ok)
 
-	assert.Equal(t, "ruby:2.0", res.Image.Name)
+	assert.Equal(t, "ruby:2.6", res.Image.Name)
 	assert.Equal(t, []string{"/bin/sh"}, res.Image.Entrypoint)
 	require.Len(t, res.Services, 2)
 	assert.Equal(t, "postgresql:9.5", res.Services[0].Name)
@@ -706,9 +707,8 @@ func TestUnknownPatchTrace(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	defer server.Close()
 
-	_, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent, 0)
-	assert.Equal(t, UpdateNotFound, state)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+	assert.Equal(t, UpdateNotFound, result.State)
 }
 
 func TestForbiddenPatchTrace(t *testing.T) {
@@ -719,9 +719,8 @@ func TestForbiddenPatchTrace(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	defer server.Close()
 
-	_, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent, 0)
-	assert.Equal(t, UpdateAbort, state)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+	assert.Equal(t, UpdateAbort, result.State)
 }
 
 func TestPatchTrace(t *testing.T) {
@@ -733,20 +732,17 @@ func TestPatchTrace(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	defer server.Close()
 
-	endOffset, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent, 0)
-	assert.Equal(t, UpdateSucceeded, state)
-	assert.Equal(t, len(patchTraceContent), endOffset)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+	assert.Equal(t, UpdateSucceeded, result.State)
+	assert.Equal(t, len(patchTraceContent), result.SentOffset)
 
-	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent[3:], 3)
-	assert.Equal(t, UpdateSucceeded, state)
-	assert.Equal(t, len(patchTraceContent), endOffset)
+	result = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent[3:], 3)
+	assert.Equal(t, UpdateSucceeded, result.State)
+	assert.Equal(t, len(patchTraceContent), result.SentOffset)
 
-	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent[3:10], 3)
-	assert.Equal(t, UpdateSucceeded, state)
-	assert.Equal(t, 10, endOffset)
+	result = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent[3:10], 3)
+	assert.Equal(t, UpdateSucceeded, result.State)
+	assert.Equal(t, 10, result.SentOffset)
 }
 
 func TestRangeMismatchPatchTrace(t *testing.T) {
@@ -762,20 +758,17 @@ func TestRangeMismatchPatchTrace(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	defer server.Close()
 
-	endOffset, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent[11:], 11)
-	assert.Equal(t, UpdateRangeMismatch, state)
-	assert.Equal(t, 10, endOffset)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent[11:], 11)
+	assert.Equal(t, UpdateRangeMismatch, result.State)
+	assert.Equal(t, 10, result.SentOffset)
 
-	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent[15:], 15)
-	assert.Equal(t, UpdateRangeMismatch, state)
-	assert.Equal(t, 10, endOffset)
+	result = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent[15:], 15)
+	assert.Equal(t, UpdateRangeMismatch, result.State)
+	assert.Equal(t, 10, result.SentOffset)
 
-	endOffset, state = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent[5:], 5)
-	assert.Equal(t, UpdateSucceeded, state)
-	assert.Equal(t, len(patchTraceContent), endOffset)
+	result = client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent[5:], 5)
+	assert.Equal(t, UpdateSucceeded, result.State)
+	assert.Equal(t, len(patchTraceContent), result.SentOffset)
 }
 
 func TestJobFailedStatePatchTrace(t *testing.T) {
@@ -787,9 +780,8 @@ func TestJobFailedStatePatchTrace(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	defer server.Close()
 
-	_, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent, 0)
-	assert.Equal(t, UpdateAbort, state)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+	assert.Equal(t, UpdateAbort, result.State)
 }
 
 func TestPatchTraceCantConnect(t *testing.T) {
@@ -798,9 +790,8 @@ func TestPatchTraceCantConnect(t *testing.T) {
 	server, client, config := getPatchServer(t, handler)
 	server.Close()
 
-	_, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-		patchTraceContent, 0)
-	assert.Equal(t, UpdateFailed, state)
+	result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+	assert.Equal(t, UpdateFailed, result.State)
 }
 
 func TestPatchTraceUpdatedTrace(t *testing.T) {
@@ -860,11 +851,11 @@ func TestPatchTraceUpdatedTrace(t *testing.T) {
 			defer server.Close()
 
 			traceContent = append(traceContent, update.traceUpdate...)
-			endOffset, result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
+			result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
 				traceContent[sentTrace:], sentTrace)
-			assert.Equal(t, update.expectedResult, result)
+			assert.Equal(t, update.expectedResult, result.State)
 
-			sentTrace = endOffset
+			sentTrace = result.SentOffset
 		})
 	}
 }
@@ -916,9 +907,8 @@ func TestPatchTraceContentRangeAndLength(t *testing.T) {
 			server, client, config := getPatchServer(t, handler)
 			defer server.Close()
 
-			_, result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-				test.trace, 0)
-			assert.Equal(t, test.expectedResult, result)
+			result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, test.trace, 0)
+			assert.Equal(t, test.expectedResult, result.State)
 		})
 	}
 }
@@ -947,6 +937,62 @@ func TestPatchTraceContentRangeHeaderValues(t *testing.T) {
 		patchTraceContent, 0)
 }
 
+func TestPatchTraceUpdateIntervalHeaderHandling(t *testing.T) {
+	tests := map[string]struct {
+		sendUpdateIntervalHeader  bool
+		updateIntervalHeaderValue string
+		expectedUpdateInterval    time.Duration
+	}{
+		"header set to negative integer": {
+			sendUpdateIntervalHeader:  true,
+			updateIntervalHeaderValue: "-10",
+			expectedUpdateInterval:    -10 * time.Second,
+		},
+		"header set to zero": {
+			sendUpdateIntervalHeader:  true,
+			updateIntervalHeaderValue: "0",
+			expectedUpdateInterval:    time.Duration(0),
+		},
+		"header set to positive integer": {
+			sendUpdateIntervalHeader:  true,
+			updateIntervalHeaderValue: "10",
+			expectedUpdateInterval:    10 * time.Second,
+		},
+		"header set to invalid format": {
+			sendUpdateIntervalHeader:  true,
+			updateIntervalHeaderValue: "some text",
+			expectedUpdateInterval:    time.Duration(0),
+		},
+		"empty header": {
+			sendUpdateIntervalHeader:  true,
+			updateIntervalHeaderValue: "",
+			expectedUpdateInterval:    time.Duration(0),
+		},
+		"header not set": {
+			sendUpdateIntervalHeader: false,
+			expectedUpdateInterval:   time.Duration(0),
+		},
+	}
+
+	for tn, tt := range tests {
+		t.Run(tn, func(t *testing.T) {
+			handler := func(w http.ResponseWriter, r *http.Request, body []byte, offset, limit int) {
+				if tt.sendUpdateIntervalHeader {
+					w.Header().Add(traceUpdateIntervalHeader, tt.updateIntervalHeaderValue)
+				}
+
+				w.WriteHeader(http.StatusAccepted)
+			}
+
+			server, client, config := getPatchServer(t, handler)
+			defer server.Close()
+
+			result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+			assert.Equal(t, tt.expectedUpdateInterval, result.NewUpdateInterval)
+		})
+	}
+}
+
 func TestAbortedPatchTrace(t *testing.T) {
 	statuses := []string{"canceled", "failed"}
 
@@ -960,43 +1006,50 @@ func TestAbortedPatchTrace(t *testing.T) {
 			server, client, config := getPatchServer(t, handler)
 			defer server.Close()
 
-			_, state := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken},
-				patchTraceContent, 0)
-			assert.Equal(t, UpdateAbort, state)
+			result := client.PatchTrace(config, &JobCredentials{ID: 1, Token: patchToken}, patchTraceContent, 0)
+			assert.Equal(t, UpdateAbort, result.State)
 		})
 	}
 }
 
 func checkTestArtifactsUploadHandlerContent(w http.ResponseWriter, r *http.Request, body string) {
-	switch body {
-	case "too-large":
-		w.WriteHeader(http.StatusRequestEntityTooLarge)
+	cases := map[string]struct {
+		formValueKey string
+		statusCode   int
+	}{
+		"too-large": {
+			statusCode: http.StatusRequestEntityTooLarge,
+		},
+		"content": {
+			statusCode: http.StatusCreated,
+		},
+		"zip": {
+			statusCode:   http.StatusCreated,
+			formValueKey: "artifact_format",
+		},
+		"gzip": {
+			statusCode:   http.StatusCreated,
+			formValueKey: "artifact_format",
+		},
+		"junit": {
+			statusCode:   http.StatusCreated,
+			formValueKey: "artifact_type",
+		},
+	}
+
+	testCase, ok := cases[body]
+	if !ok {
+		w.WriteHeader(http.StatusBadRequest)
 		return
+	}
 
-	case "content":
-		w.WriteHeader(http.StatusCreated)
-		return
-
-	case "zip":
-		if r.FormValue("artifact_format") == "zip" {
-			w.WriteHeader(http.StatusCreated)
-			return
-		}
-
-	case "gzip":
-		if r.FormValue("artifact_format") == "gzip" {
-			w.WriteHeader(http.StatusCreated)
-			return
-		}
-
-	case "junit":
-		if r.FormValue("artifact_type") == "junit" {
-			w.WriteHeader(http.StatusCreated)
+	if len(testCase.formValueKey) > 0 {
+		if r.FormValue(testCase.formValueKey) != body {
 			return
 		}
 	}
 
-	w.WriteHeader(http.StatusBadRequest)
+	w.WriteHeader(testCase.statusCode)
 }
 
 func testArtifactsUploadHandler(w http.ResponseWriter, r *http.Request, t *testing.T) {
